Roadmap
=======

The following models and categories are planned for future development.
Contributions are welcome!

.. toctree::
   :maxdepth: 1

   roadmap_monetary_policy_models
   roadmap_quantity_of_money_theory
   roadmap_exchange_rate_models
   roadmap_macroeconomic_models
   roadmap_microeconomic_models
   roadmap_discounted_cash_flow_models
   roadmap_financial_models
   roadmap_fiscal_policy_models
   roadmap_other_economic_models
